aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/auth/auth.php
diff options
context:
space:
mode:
authorPaul Sohier <paul999@phpbb.com>2015-10-24 17:47:04 +0200
committerPaul Sohier <paul999@phpbb.com>2015-10-24 17:47:04 +0200
commit2a218c29597524c3bab1070cdb1f9f58e31c5bb5 (patch)
tree7484581ccf628385f5ee82ff474cf8af70163034 /phpBB/phpbb/auth/auth.php
parent7615a5c22ff733b2c0ac9a30029104cc9ab9a542 (diff)
downloadforums-2a218c29597524c3bab1070cdb1f9f58e31c5bb5.tar
forums-2a218c29597524c3bab1070cdb1f9f58e31c5bb5.tar.gz
forums-2a218c29597524c3bab1070cdb1f9f58e31c5bb5.tar.bz2
forums-2a218c29597524c3bab1070cdb1f9f58e31c5bb5.tar.xz
forums-2a218c29597524c3bab1070cdb1f9f58e31c5bb5.zip
[ticket/14258] Add event into auth::login before session creation
Update comments regarding variables. PHPBB3-14258
Diffstat (limited to 'phpBB/phpbb/auth/auth.php')
-rw-r--r--phpBB/phpbb/auth/auth.php15
1 files changed, 7 insertions, 8 deletions
diff --git a/phpBB/phpbb/auth/auth.php b/phpBB/phpbb/auth/auth.php
index fa168a5325..148a97c68e 100644
--- a/phpBB/phpbb/auth/auth.php
+++ b/phpBB/phpbb/auth/auth.php
@@ -984,14 +984,13 @@ class auth
}
/**
- * This event is triggered just after the user has been checked if he has a valid username/password,
- * but before the actual session creation.
+ * TEvent is triggered after checking for valid username and password, and before the actual session creation.
*
* @event core.auth_login_before_session_create
* @var array login Variable containing login array value
* @var bool admin Variable containing if is logging into the acp
* @var string username Variable containing the username
* @var bool autologin Variable containing if this is by auto login
* @since 3.1.7-RC1
*/
$vars = array(
@@ -1000,7 +999,7 @@ class auth
'username',
'autologin',
);
- extract($phpbb_dispatcher->trigger_event('core.auth_login_before_session_create', compact($vars)));
+ extract($phpbb_dispatcher->trigger_event('core.auth_login_session_create_before', compact($vars)));
// If login succeeded, we will log the user in... else we pass the login array through...
if ($login['status'] == LOGIN_SUCCESS)
@@ -984,14 +984,13 @@ class auth
*
- * @event core.auth_login_before_session_create
- * @var array login Variable containing login array value
- * @var bool admin Variable containing if is logging into the acp
- * @var string username Variable containing the username
- * @var bool autologin Variable containing if this is by auto login
+ * @event core.auth_login_session_create_before
+ * @var array login Variable containing login array
+ * @var bool admin Boolean variable whether user is logging into the ACP
+ * @var string username Username of user to log in
+ * @var bool autologin Boolean variable signaling whether login is triggered via auto login
* @since 3.1.7-RC1
*/